@@ -13,11 +13,12 @@ if(identical(as.logical(service), TRUE)) {
    user    <- Sys.getenv("ODBC_USER")
    if ("" != user) {
        host    <- Sys.getenv("ODBC_HOST")
-       if ("" == host)     host <- Sys.info()["nodename"] 
-       if ("" == passwd)   passwd <- NULL
+       if ("" != host) warning(
+	 "host name is note used. The connection is taken from the .odbc.ini file")
        passwd  <- Sys.getenv("ODBC_PASSWD")
+       if ("" == passwd)   passwd <- NULL
        #  See  ?odbcConnect   ?odbcDriverConnect
-       con <- odbcConnect(dsn=dbname, uid=user, pwd=passwd, connection=host)  
+       con <- odbcConnect(dsn=dbname, uid=user, pwd=passwd) #, connection=host)  
     } else {
        if (is.null(dbname))   dbname <- "test"  # NULL dbname causes problem
        con <-  odbcConnect(dsn=dbname) # pass user/passwd/host in ~/.odbc.ini
